(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0af42a"],{"0e21":function(e,a,n){(function(e,n){n(a)})(0,(function(e){"use strict";var a="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={weekdays:{shorthand:["Ned","Pon","Uto","Sre","Čet","Pet","Sub"],longhand:["Nedelja","Ponedeljak","Utorak","Sreda","Četvrtak","Petak","Subota"]},months:{shorthand:["Jan","Feb","Mar","Apr","Maj","Jun","Jul","Avg","Sep","Okt","Nov","Dec"],longhand:["Januar","Februar","Mart","April","Maj","Jun","Jul","Avgust","Septembar","Oktobar","Novembar","Decembar"]},firstDayOfWeek:1,weekAbbreviation:"Ned.",rangeSeparator:" do ",time_24hr:!0};a.l10ns.sr=n;var r=a.l10ns;e.Serbian=n,e.default=r,Object.defineProperty(e,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0af42a.5db45a3c.js.map