(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0afa88"],{"0eeb":function(e,t){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"ca",week:{dow:1,doy:4},buttonText:{prev:"Anterior",next:"Següent",today:"Avui",month:"Mes",week:"Setmana",day:"Dia",list:"Agenda"},weekText:"Set",allDayText:"Tot el dia",moreLinkText:"més",noEventsText:"No hi ha esdeveniments per mostrar"};return e}())}}]);
//# sourceMappingURL=chunk-2d0afa88.c9c18f13.js.map