(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0cf866"],{"63a4":function(e,a){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"sv",week:{dow:1,doy:4},buttonText:{prev:"Förra",next:"Nästa",today:"Idag",month:"Månad",week:"Vecka",day:"Dag",list:"Program"},weekText:"v.",allDayText:"Heldag",moreLinkText:"till",noEventsText:"Inga händelser att visa"};return e}())}}]);
//# sourceMappingURL=chunk-2d0cf866.a5a30a3f.js.map