(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d225f65"],{e741:function(e,o){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"pt",week:{dow:1,doy:4},buttonText:{prev:"Anterior",next:"Seguinte",today:"Hoje",month:"Mês",week:"Semana",day:"Dia",list:"Agenda"},weekText:"Sem",allDayText:"Todo o dia",moreLinkText:"mais",noEventsText:"Não há eventos para mostrar"};return e}())}}]);
//# sourceMappingURL=chunk-2d225f65.cd05c84d.js.map