(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0d65b1"],{"71cd":function(n,e){FullCalendar.globalLocales.push(function(){"use strict";var n={code:"vi",week:{dow:1,doy:4},buttonText:{prev:"Trước",next:"Tiếp",today:"Hôm nay",month:"Tháng",week:"Tuần",day:"Ngày",list:"Lịch biểu"},weekText:"Tu",allDayText:"Cả ngày",moreLinkText(n){return"+ thêm "+n},noEventsText:"Không có sự kiện để hiển thị"};return n}())}}]);
//# sourceMappingURL=chunk-2d0d65b1.e9f8b79e.js.map