(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0f064b"],{"9bd0":function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"zh-cn",week:{dow:1,doy:4},buttonText:{prev:"上月",next:"下月",today:"今天",month:"月",week:"周",day:"日",list:"日程"},weekText:"周",allDayText:"全天",moreLinkText(e){return"另外 "+e+" 个"},noEventsText:"没有事件显示"};return e}())}}]);
//# sourceMappingURL=chunk-2d0f064b.8f8062e1.js.map