(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0ab6f5"],{"14ea":function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"kk",week:{dow:1,doy:7},buttonText:{prev:"Алдыңғы",next:"Келесі",today:"Бүгін",month:"Ай",week:"Апта",day:"Күн",list:"Күн тәртібі"},weekText:"Не",allDayText:"Күні бойы",moreLinkText(e){return"+ тағы "+e},noEventsText:"Көрсету үшін оқиғалар жоқ"};return e}())}}]);
//# sourceMappingURL=chunk-2d0ab6f5.f9548158.js.map