(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c8256"],{5445:function(n,o,e){(function(n,e){e(o)})(0,(function(n){"use strict";var o="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["일","월","화","수","목","금","토"],longhand:["일요일","월요일","화요일","수요일","목요일","금요일","토요일"]},months:{shorthand:["1월","2월","3월","4월","5월","6월","7월","8월","9월","10월","11월","12월"],longhand:["1월","2월","3월","4월","5월","6월","7월","8월","9월","10월","11월","12월"]},ordinal:function(){return"일"},rangeSeparator:" ~ "};o.l10ns.ko=e;var a=o.l10ns;n.Korean=e,n.default=a,Object.defineProperty(n,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0c8256.5346d77b.js.map