(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0abc94"],{1780:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"it",week:{dow:1,doy:4},buttonText:{prev:"Prec",next:"Succ",today:"Oggi",month:"Mese",week:"Settimana",day:"Giorno",list:"Agenda"},weekText:"Sm",allDayText:"Tutto il giorno",moreLinkText(e){return"+altri "+e},noEventsText:"Non ci sono eventi da visualizzare"};return e}())}}]);
//# sourceMappingURL=chunk-2d0abc94.8cbbf4e2.js.map