(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0a38b9"],{"0344":function(e,n,t){"use strict";Object.defineProperty(n,"__esModule",{value:!0});var o={code:"fr",buttonText:{prev:"Précédent",next:"Suivant",today:"Aujourd'hui",year:"Année",month:"Mois",week:"Semaine",day:"Jour",list:"Mon planning"},weekText:"Sem.",allDayText:"Toute la journée",moreLinkText:"en plus",noEventsText:"Aucun événement à afficher"};n.default=o}}]);
//# sourceMappingURL=chunk-2d0a38b9.77d3b39a.js.map