(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d22252c"],{cdb7:function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o={code:"ka",week:{dow:1,doy:7},buttonText:{prev:"წინა",next:"შემდეგი",today:"დღეს",month:"თვე",week:"კვირა",day:"დღე",list:"დღის წესრიგი"},weekText:"კვ",allDayText:"მთელი დღე",moreLinkText(e){return"+ კიდევ "+e},noEventsText:"ღონისძიებები არ არის"};t.default=o}}]);
//# sourceMappingURL=chunk-2d22252c.a6fd3df6.js.map