(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d2288d7"],{da59:function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o={code:"hi",week:{dow:0,doy:6},buttonText:{prev:"पिछला",next:"अगला",today:"आज",month:"महीना",week:"सप्ताह",day:"दिन",list:"कार्यसूची"},weekText:"हफ्ता",allDayText:"सभी दिन",moreLinkText(e){return"+अधिक "+e},noEventsText:"कोई घटनाओं को प्रदर्शित करने के लिए"};t.default=o}}]);
//# sourceMappingURL=chunk-2d2288d7.092734c8.js.map