(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0d6922"],{"72b3":function(e,t){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"fi",week:{dow:1,doy:4},buttonText:{prev:"Edellinen",next:"Seuraava",today:"Tänään",month:"Kuukausi",week:"Viikko",day:"Päivä",list:"Tapahtumat"},weekText:"Vk",allDayText:"Koko päivä",moreLinkText:"lisää",noEventsText:"Ei näytettäviä tapahtumia"};return e}())}}]);
//# sourceMappingURL=chunk-2d0d6922.3448e6a1.js.map