(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d22290e"],{cec9:function(a,n,e){(function(a,e){e(n)})(0,(function(a){"use strict";var n="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["Ya","Du","Se","Cho","Pa","Ju","Sha"],longhand:["Yakshanba","Dushanba","Seshanba","Chorshanba","Payshanba","Juma","Shanba"]},months:{shorthand:["Yan","Fev","Mar","Apr","May","Iyun","Iyul","Avg","Sen","Okt","Noy","Dek"],longhand:["Yanvar","Fevral","Mart","Aprel","May","Iyun","Iyul","Avgust","Sentabr","Oktabr","Noyabr","Dekabr"]},firstDayOfWeek:1,ordinal:function(){return""},rangeSeparator:" — ",weekAbbreviation:"Hafta",scrollTitle:"Kattalashtirish uchun aylantiring",toggleTitle:"O‘tish uchun bosing",amPM:["AM","PM"],yearAriaLabel:"Yil",time_24hr:!0};n.l10ns["uz_latn"]=e;var t=n.l10ns;a.UzbekLatin=e,a.default=t,Object.defineProperty(a,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d22290e.2a948903.js.map