(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d238263"],{fdc2:function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o={code:"ru",week:{dow:1,doy:4},buttonText:{prev:"Пред",next:"След",today:"Сегодня",month:"Месяц",week:"Неделя",day:"День",list:"Повестка дня"},weekText:"Нед",allDayText:"Весь день",moreLinkText(e){return"+ ещё "+e},noEventsText:"Нет событий для отображения"};t.default=o}}]);
//# sourceMappingURL=chunk-2d238263.1a174b82.js.map