(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d21d12f"],{d06c:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"tr",week:{dow:1,doy:7},buttonText:{prev:"geri",next:"ileri",today:"bugün",month:"Ay",week:"Hafta",day:"Gün",list:"Ajanda"},weekText:"Hf",allDayText:"Tüm gün",moreLinkText:"daha fazla",noEventsText:"Gösterilecek etkinlik yok"};return e}())}}]);
//# sourceMappingURL=chunk-2d21d12f.d8bbd63f.js.map