(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d22cfa9"],{f614:function(e,t,o){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var n={code:"el",week:{dow:1,doy:4},buttonText:{prev:"Προηγούμενος",next:"Επόμενος",today:"Σήμερα",month:"Μήνας",week:"Εβδομάδα",day:"Ημέρα",list:"Ατζέντα"},weekText:"Εβδ",allDayText:"Ολοήμερο",moreLinkText:"περισσότερα",noEventsText:"Δεν υπάρχουν γεγονότα προς εμφάνιση"};t.default=n}}]);
//# sourceMappingURL=chunk-2d22cfa9.f9d17702.js.map