(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d2227e1"],{cf9a:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"ka",week:{dow:1,doy:7},buttonText:{prev:"წინა",next:"შემდეგი",today:"დღეს",month:"თვე",week:"კვირა",day:"დღე",list:"დღის წესრიგი"},weekText:"კვ",allDayText:"მთელი დღე",moreLinkText(e){return"+ კიდევ "+e},noEventsText:"ღონისძიებები არ არის"};return e}())}}]);
//# sourceMappingURL=chunk-2d2227e1.d53c358e.js.map