(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d22d73b"],{f80c:function(a,n,e){(function(a,e){e(n)})(0,(function(a){"use strict";var n="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["Paz","Pzt","Sal","Çar","Per","Cum","Cmt"],longhand:["Pazar","Pazartesi","Salı","Çarşamba","Perşembe","Cuma","Cumartesi"]},months:{shorthand:["Oca","Şub","Mar","Nis","May","Haz","Tem","Ağu","Eyl","Eki","Kas","Ara"],longhand:["Ocak","Şubat","Mart","Nisan","Mayıs","Haziran","Temmuz","Ağustos","Eylül","Ekim","Kasım","Aralık"]},firstDayOfWeek:1,ordinal:function(){return"."},rangeSeparator:" - ",weekAbbreviation:"Hf",scrollTitle:"Artırmak için kaydırın",toggleTitle:"Aç/Kapa",amPM:["ÖÖ","ÖS"],time_24hr:!0};n.l10ns.tr=e;var r=n.l10ns;a.Turkish=e,a.default=r,Object.defineProperty(a,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d22d73b.50c65548.js.map