(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0b991c"],{3405:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"uk",week:{dow:1,doy:7},buttonText:{prev:"Попередній",next:"далі",today:"Сьогодні",month:"Місяць",week:"Тиждень",day:"День",list:"Порядок денний"},weekText:"Тиж",allDayText:"Увесь день",moreLinkText(e){return"+ще "+e+"..."},noEventsText:"Немає подій для відображення"};return e}())}}]);
//# sourceMappingURL=chunk-2d0b991c.06c9bed9.js.map