(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0a4b53"],{"081f":function(e,n,o){"use strict";Object.defineProperty(n,"__esModule",{value:!0});var d={code:"en-nz",week:{dow:1,doy:4}};n.default=d}}]);
//# sourceMappingURL=chunk-2d0a4b53.8ce56c24.js.map