(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0b92a3"],{"327e":function(e,n,t){"use strict";Object.defineProperty(n,"__esModule",{value:!0});var a={code:"sk",week:{dow:1,doy:4},buttonText:{prev:"Predchádzajúci",next:"Nasledujúci",today:"Dnes",month:"Mesiac",week:"Týždeň",day:"Deň",list:"Rozvrh"},weekText:"Ty",allDayText:"Celý deň",moreLinkText(e){return"+ďalšie: "+e},noEventsText:"Žiadne akcie na zobrazenie"};n.default=a}}]);
//# sourceMappingURL=chunk-2d0b92a3.1eecf553.js.map