(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0e9367"],{"8d27":function(e,o){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"es",week:{dow:1,doy:4},buttonText:{prev:"Ant",next:"Sig",today:"Hoy",month:"Mes",week:"Semana",day:"Día",list:"Agenda"},weekText:"Sm",allDayText:"Todo el día",moreLinkText:"más",noEventsText:"No hay eventos para mostrar"};return e}())}}]);
//# sourceMappingURL=chunk-2d0e9367.cac3e2be.js.map