(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d210259"],{b73a:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"et",week:{dow:1,doy:4},buttonText:{prev:"Eelnev",next:"Järgnev",today:"Täna",month:"Kuu",week:"Nädal",day:"Päev",list:"Päevakord"},weekText:"näd",allDayText:"Kogu päev",moreLinkText(e){return"+ veel "+e},noEventsText:"Kuvamiseks puuduvad sündmused"};return e}())}}]);
//# sourceMappingURL=chunk-2d210259.c242d0e1.js.map