(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0d3307"],{"5c69":function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"nb",week:{dow:1,doy:4},buttonText:{prev:"Forrige",next:"Neste",today:"I dag",month:"Måned",week:"Uke",day:"Dag",list:"Agenda"},weekText:"Uke",allDayText:"Hele dagen",moreLinkText:"til",noEventsText:"Ingen hendelser å vise"};return e}())}}]);
//# sourceMappingURL=chunk-2d0d3307.68c4d6d4.js.map