(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0da953"],{"6be6":function(e,a){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"eu",week:{dow:1,doy:7},buttonText:{prev:"Aur",next:"Hur",today:"Gaur",month:"Hilabetea",week:"Astea",day:"Eguna",list:"Agenda"},weekText:"As",allDayText:"Egun osoa",moreLinkText:"gehiago",noEventsText:"Ez dago ekitaldirik erakusteko"};return e}())}}]);
//# sourceMappingURL=chunk-2d0da953.176f5558.js.map