(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0e502b"],{9350:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"pl",week:{dow:1,doy:4},buttonText:{prev:"Poprzedni",next:"Następny",today:"Dziś",month:"Miesiąc",week:"Tydzień",day:"Dzień",list:"Plan dnia"},weekText:"Tydz",allDayText:"Cały dzień",moreLinkText:"więcej",noEventsText:"Brak wydarzeń do wyświetlenia"};return e}())}}]);
//# sourceMappingURL=chunk-2d0e502b.833d3d9d.js.map