(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0b8a58"],{3027:function(e,a,n){"use strict";Object.defineProperty(a,"__esModule",{value:!0});var t={code:"is",week:{dow:1,doy:4},buttonText:{prev:"Fyrri",next:"Næsti",today:"Í dag",month:"Mánuður",week:"Vika",day:"Dagur",list:"Dagskrá"},weekText:"Vika",allDayText:"Allan daginn",moreLinkText:"meira",noEventsText:"Engir viðburðir til að sýna"};a.default=t}}]);
//# sourceMappingURL=chunk-2d0b8a58.c2d6da76.js.map