(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0ac96c"],{"19d2":function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"fr-ch",week:{dow:1,doy:4},buttonText:{prev:"Précédent",next:"Suivant",today:"Courant",year:"Année",month:"Mois",week:"Semaine",day:"Jour",list:"Mon planning"},weekText:"Sm",allDayText:"Toute la journée",moreLinkText:"en plus",noEventsText:"Aucun événement à afficher"};return e}())}}]);
//# sourceMappingURL=chunk-2d0ac96c.0a4202b3.js.map