(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0cfa5b"],{6539:function(e,a,n){"use strict";Object.defineProperty(a,"__esModule",{value:!0});var t={code:"ms",week:{dow:1,doy:7},buttonText:{prev:"Sebelum",next:"Selepas",today:"hari ini",month:"Bulan",week:"Minggu",day:"Hari",list:"Agenda"},weekText:"Mg",allDayText:"Sepanjang hari",moreLinkText(e){return"masih ada "+e+" acara"},noEventsText:"Tiada peristiwa untuk dipaparkan"};a.default=t}}]);
//# sourceMappingURL=chunk-2d0cfa5b.c6a8c810.js.map