(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0aaf78"],{"12ef":function(e,t){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"zh-tw",buttonText:{prev:"上月",next:"下月",today:"今天",month:"月",week:"週",day:"天",list:"活動列表"},weekText:"周",allDayText:"整天",moreLinkText:"顯示更多",noEventsText:"没有任何活動"};return e}())}}]);
//# sourceMappingURL=chunk-2d0aaf78.52d3163d.js.map