(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d2386b5"],{feff:function(n,o,d){(function(n,d){d(o)})(0,(function(n){"use strict";var o="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},d={weekdays:{shorthand:["रवि","सोम","मंगल","बुध","गुरु","शुक्र","शनि"],longhand:["रविवार","सोमवार","मंगलवार","बुधवार","गुरुवार","शुक्रवार","शनिवार"]},months:{shorthand:["जन","फर","मार्च","अप्रेल","मई","जून","जूलाई","अग","सित","अक्ट","नव","दि"],longhand:["जनवरी ","फरवरी","मार्च","अप्रेल","मई","जून","जूलाई","अगस्त ","सितम्बर","अक्टूबर","नवम्बर","दिसम्बर"]}};o.l10ns.hi=d;var e=o.l10ns;n.Hindi=d,n.default=e,Object.defineProperty(n,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d2386b5.5dc97773.js.map