(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0cb6c7"],{"4a37":function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o={code:"th",week:{dow:1,doy:4},buttonText:{prev:"ก่อนหน้า",next:"ถัดไป",prevYear:"ปีก่อนหน้า",nextYear:"ปีถัดไป",year:"ปี",today:"วันนี้",month:"เดือน",week:"สัปดาห์",day:"วัน",list:"กำหนดการ"},weekText:"สัปดาห์",allDayText:"ตลอดวัน",moreLinkText:"เพิ่มเติม",noEventsText:"ไม่มีกิจกรรมที่จะแสดง"};t.default=o}}]);
//# sourceMappingURL=chunk-2d0cb6c7.37a7b04e.js.map