(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0b2758"],{"23cd":function(e,o,t){"use strict";Object.defineProperty(o,"__esModule",{value:!0});var a={code:"es",week:{dow:1,doy:4},buttonText:{prev:"Ant",next:"Sig",today:"Hoy",month:"Mes",week:"Semana",day:"Día",list:"Agenda"},weekText:"Sm",allDayText:"Todo el día",moreLinkText:"más",noEventsText:"No hay eventos para mostrar"};o.default=a}}]);
//# sourceMappingURL=chunk-2d0b2758.52dc1329.js.map