(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0b9f58"],{"34bc":function(a,e){FullCalendar.globalLocales.push(function(){"use strict";var a={code:"ms",week:{dow:1,doy:7},buttonText:{prev:"Sebelum",next:"Selepas",today:"hari ini",month:"Bulan",week:"Minggu",day:"Hari",list:"Agenda"},weekText:"Mg",allDayText:"Sepanjang hari",moreLinkText(a){return"masih ada "+a+" acara"},noEventsText:"Tiada peristiwa untuk dipaparkan"};return a}())}}]);
//# sourceMappingURL=chunk-2d0b9f58.975ff6ee.js.map