(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c91c4"],{"586a":function(e,t){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"th",week:{dow:1,doy:4},buttonText:{prev:"ก่อนหน้า",next:"ถัดไป",prevYear:"ปีก่อนหน้า",nextYear:"ปีถัดไป",year:"ปี",today:"วันนี้",month:"เดือน",week:"สัปดาห์",day:"วัน",list:"กำหนดการ"},weekText:"สัปดาห์",allDayText:"ตลอดวัน",moreLinkText:"เพิ่มเติม",noEventsText:"ไม่มีกิจกรรมที่จะแสดง"};return e}())}}]);
//# sourceMappingURL=chunk-2d0c91c4.a87bd588.js.map