(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d217a1d"],{c80b:function(n,h,T){(function(n,T){T(h)})(0,(function(n){"use strict";var h="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},T={weekdays:{shorthand:["CN","T2","T3","T4","T5","T6","T7"],longhand:["Chủ nhật","Thứ hai","Thứ ba","Thứ tư","Thứ năm","Thứ sáu","Thứ bảy"]},months:{shorthand:["Th1","Th2","Th3","Th4","Th5","Th6","Th7","Th8","Th9","Th10","Th11","Th12"],longhand:["Tháng một","Tháng hai","Tháng ba","Tháng tư","Tháng năm","Tháng sáu","Tháng bảy","Tháng tám","Tháng chín","Tháng mười","Tháng 11","Tháng 12"]},firstDayOfWeek:1,rangeSeparator:" đến "};h.l10ns.vn=T;var a=h.l10ns;n.Vietnamese=T,n.default=a,Object.defineProperty(n,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d217a1d.1b026a06.js.map