(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0df06b"],{"87c9":function(e,o){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"gl",week:{dow:1,doy:4},buttonText:{prev:"Ant",next:"Seg",today:"Hoxe",month:"Mes",week:"Semana",day:"Día",list:"Axenda"},weekText:"Sm",allDayText:"Todo o día",moreLinkText:"máis",noEventsText:"Non hai eventos para amosar"};return e}())}}]);
//# sourceMappingURL=chunk-2d0df06b.0ac20575.js.map