(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d230542"],{ec8f:function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o={code:"lb",week:{dow:1,doy:4},buttonText:{prev:"Zréck",next:"Weider",today:"Haut",month:"Mount",week:"Woch",day:"Dag",list:"Terminiwwersiicht"},weekText:"W",allDayText:"Ganzen Dag",moreLinkText:"méi",noEventsText:"Nee Evenementer ze affichéieren"};t.default=o}}]);
//# sourceMappingURL=chunk-2d230542.53edd8c0.js.map