(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d2101ea"],{b710:function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o={code:"ne",week:{dow:7,doy:1},buttonText:{prev:"अघिल्लो",next:"अर्को",today:"आज",month:"महिना",week:"हप्ता",day:"दिन",list:"सूची"},weekText:"हप्ता",allDayText:"दिनभरि",moreLinkText:"थप लिंक",noEventsText:"देखाउनको लागि कुनै घटनाहरू छैनन्"};t.default=o}}]);
//# sourceMappingURL=chunk-2d2101ea.63a8e4f3.js.map