(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d21648f"],{c28b:function(e,a){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"bs",week:{dow:1,doy:7},buttonText:{prev:"Prošli",next:"Sljedeći",today:"Danas",month:"Mjesec",week:"Sedmica",day:"Dan",list:"Raspored"},weekText:"Sed",allDayText:"Cijeli dan",moreLinkText(e){return"+ još "+e},noEventsText:"Nema događaja za prikazivanje"};return e}())}}]);
//# sourceMappingURL=chunk-2d21648f.e925aefa.js.map