(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0b8b22"],{"307f":function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o={code:"kk",week:{dow:1,doy:7},buttonText:{prev:"Алдыңғы",next:"Келесі",today:"Бүгін",month:"Ай",week:"Апта",day:"Күн",list:"Күн тәртібі"},weekText:"Не",allDayText:"Күні бойы",moreLinkText(e){return"+ тағы "+e},noEventsText:"Көрсету үшін оқиғалар жоқ"};t.default=o}}]);
//# sourceMappingURL=chunk-2d0b8b22.37fd6409.js.map