(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d238609"],{feb6:function(e,t){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"he",direction:"rtl",buttonText:{prev:"הקודם",next:"הבא",today:"היום",month:"חודש",week:"שבוע",day:"יום",list:"סדר יום"},allDayText:"כל היום",moreLinkText:"אחר",noEventsText:"אין אירועים להצגה",weekText:"שבוע"};return e}())}}]);
//# sourceMappingURL=chunk-2d238609.91001a8a.js.map