(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d21d4c1"],{d164:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"lb",week:{dow:1,doy:4},buttonText:{prev:"Zréck",next:"Weider",today:"Haut",month:"Mount",week:"Woch",day:"Dag",list:"Terminiwwersiicht"},weekText:"W",allDayText:"Ganzen Dag",moreLinkText:"méi",noEventsText:"Nee Evenementer ze affichéieren"};return e}())}}]);
//# sourceMappingURL=chunk-2d21d4c1.46f792d3.js.map