(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-7490c82a"],{"60da7":function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var a={code:"ca",week:{dow:1,doy:4},buttonText:{prev:"Anterior",next:"Següent",today:"Avui",month:"Mes",week:"Setmana",day:"Dia",list:"Agenda"},weekText:"Set",allDayText:"Tot el dia",moreLinkText:"més",noEventsText:"No hi ha esdeveniments per mostrar"};t.default=a}}]);
//# sourceMappingURL=chunk-7490c82a.daaac1c3.js.map