(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c4244"],{"3a22":function(e,a){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"sr",week:{dow:1,doy:7},buttonText:{prev:"Prethodna",next:"Sledeći",today:"Danas",month:"Mеsеc",week:"Nеdеlja",day:"Dan",list:"Planеr"},weekText:"Sed",allDayText:"Cеo dan",moreLinkText(e){return"+ još "+e},noEventsText:"Nеma događaja za prikaz"};return e}())}}]);
//# sourceMappingURL=chunk-2d0c4244.c8e4af07.js.map