(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0d622d"],{"70ec":function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"sr-cyrl",week:{dow:1,doy:7},buttonText:{prev:"Претходна",next:"следећи",today:"Данас",month:"Месец",week:"Недеља",day:"Дан",list:"Планер"},weekText:"Сед",allDayText:"Цео дан",moreLinkText(e){return"+ још "+e},noEventsText:"Нема догађаја за приказ"};return e}())}}]);
//# sourceMappingURL=chunk-2d0d622d.4eee0e9b.js.map