(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c8a71"],{5693:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"lv",week:{dow:1,doy:4},buttonText:{prev:"Iepr.",next:"Nāk.",today:"Šodien",month:"Mēnesis",week:"Nedēļa",day:"Diena",list:"Dienas kārtība"},weekText:"Ned.",allDayText:"Visu dienu",moreLinkText(e){return"+vēl "+e},noEventsText:"Nav notikumu"};return e}())}}]);
//# sourceMappingURL=chunk-2d0c8a71.16ba271d.js.map