(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0df0c0"],{"87f1":function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"hi",week:{dow:0,doy:6},buttonText:{prev:"पिछला",next:"अगला",today:"आज",month:"महीना",week:"सप्ताह",day:"दिन",list:"कार्यसूची"},weekText:"हफ्ता",allDayText:"सभी दिन",moreLinkText(e){return"+अधिक "+e},noEventsText:"कोई घटनाओं को प्रदर्शित करने के लिए"};return e}())}}]);
//# sourceMappingURL=chunk-2d0df0c0.235ff78c.js.map