(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c0665"],{"422c":function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"hu",week:{dow:1,doy:4},buttonText:{prev:"vissza",next:"előre",today:"ma",month:"Hónap",week:"Hét",day:"Nap",list:"Napló"},weekText:"Hét",allDayText:"Egész nap",moreLinkText:"további",noEventsText:"Nincs megjeleníthető esemény"};return e}())}}]);
//# sourceMappingURL=chunk-2d0c0665.84c75d46.js.map