(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0e88af"],{"8a5e":function(a,n,e){(function(a,e){e(n)})(0,(function(a){"use strict";var n="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["B.","B.e.","Ç.a.","Ç.","C.a.","C.","Ş."],longhand:["Bazar","Bazar ertəsi","Çərşənbə axşamı","Çərşənbə","Cümə axşamı","Cümə","Şənbə"]},months:{shorthand:["Yan","Fev","Mar","Apr","May","İyn","İyl","Avq","Sen","Okt","Noy","Dek"],longhand:["Yanvar","Fevral","Mart","Aprel","May","İyun","İyul","Avqust","Sentyabr","Oktyabr","Noyabr","Dekabr"]},firstDayOfWeek:1,ordinal:function(){return"."},rangeSeparator:" - ",weekAbbreviation:"Hf",scrollTitle:"Artırmaq üçün sürüşdürün",toggleTitle:"Aç / Bağla",amPM:["GƏ","GS"],time_24hr:!0};n.l10ns.az=e;var r=n.l10ns;a.Azerbaijan=e,a.default=r,Object.defineProperty(a,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0e88af.3a071f37.js.map