(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-74b4d726"],{"7b0b9":function(u,i,n){(function(u,n){n(i)})(0,(function(u){"use strict";var i="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={firstDayOfWeek:1,weekdays:{shorthand:["Su","Ma","Ti","Ke","To","Pe","La"],longhand:["Sunnuntai","Maanantai","Tiistai","Keskiviikko","Torstai","Perjantai","Lauantai"]},months:{shorthand:["Tammi","Helmi","Maalis","Huhti","Touko","Kesä","Heinä","Elo","Syys","Loka","Marras","Joulu"],longhand:["Tammikuu","Helmikuu","Maaliskuu","Huhtikuu","Toukokuu","Kesäkuu","Heinäkuu","Elokuu","Syyskuu","Lokakuu","Marraskuu","Joulukuu"]},ordinal:function(){return"."},time_24hr:!0};i.l10ns.fi=n;var a=i.l10ns;u.Finnish=n,u.default=a,Object.defineProperty(u,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-74b4d726.015f5c0b.js.map