(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c0ab4"],{4387:function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o={code:"zh-cn",week:{dow:1,doy:4},buttonText:{prev:"上月",next:"下月",today:"今天",month:"月",week:"周",day:"日",list:"日程"},weekText:"周",allDayText:"全天",moreLinkText(e){return"另外 "+e+" 个"},noEventsText:"没有事件显示"};t.default=o}}]);
//# sourceMappingURL=chunk-2d0c0ab4.f10ffd49.js.map