(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d20fa70"],{b518:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"sk",week:{dow:1,doy:4},buttonText:{prev:"Predchádzajúci",next:"Nasledujúci",today:"Dnes",month:"Mesiac",week:"Týždeň",day:"Deň",list:"Rozvrh"},weekText:"Ty",allDayText:"Celý deň",moreLinkText(e){return"+ďalšie: "+e},noEventsText:"Žiadne akcie na zobrazenie"};return e}())}}]);
//# sourceMappingURL=chunk-2d20fa70.5d368736.js.map