(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d2290fe"],{dc9b:function(r,a,e){(function(r,e){e(a)})(0,(function(r){"use strict";var a="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["Sun","Mán","Týs","Mik","Hós","Frí","Ley"],longhand:["Sunnudagur","Mánadagur","Týsdagur","Mikudagur","Hósdagur","Fríggjadagur","Leygardagur"]},months:{shorthand:["Jan","Feb","Mar","Apr","Mai","Jun","Jul","Aug","Sep","Okt","Nov","Des"],longhand:["Januar","Februar","Mars","Apríl","Mai","Juni","Juli","August","Septembur","Oktobur","Novembur","Desembur"]},ordinal:function(){return"."},firstDayOfWeek:1,rangeSeparator:" til ",weekAbbreviation:"vika",scrollTitle:"Rulla fyri at broyta",toggleTitle:"Trýst fyri at skifta",yearAriaLabel:"Ár",time_24hr:!0};a.l10ns.fo=e;var n=a.l10ns;r.Faroese=e,r.default=n,Object.defineProperty(r,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d2290fe.d0c0ec21.js.map