(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0bdf1c"],{"2dc7":function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"fr",buttonText:{prev:"Précédent",next:"Suivant",today:"Aujourd'hui",year:"Année",month:"Mois",week:"Semaine",day:"Jour",list:"Mon planning"},weekText:"Sem.",allDayText:"Toute la journée",moreLinkText:"en plus",noEventsText:"Aucun événement à afficher"};return e}())}}]);
//# sourceMappingURL=chunk-2d0bdf1c.34b225ab.js.map