(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0d63c2"],{"724e":function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var o={code:"mk",buttonText:{prev:"претходно",next:"следно",today:"Денес",month:"Месец",week:"Недела",day:"Ден",list:"График"},weekText:"Сед",allDayText:"Цел ден",moreLinkText(e){return"+повеќе "+e},noEventsText:"Нема настани за прикажување"};t.default=o}}]);
//# sourceMappingURL=chunk-2d0d63c2.71d074c0.js.map