(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0f15bf"],{"9ffb":function(e,t,o){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var n={code:"it",week:{dow:1,doy:4},buttonText:{prev:"Prec",next:"Succ",today:"Oggi",month:"Mese",week:"Settimana",day:"Giorno",list:"Agenda"},weekText:"Sm",allDayText:"Tutto il giorno",moreLinkText(e){return"+altri "+e},noEventsText:"Non ci sono eventi da visualizzare"};t.default=n}}]);
//# sourceMappingURL=chunk-2d0f15bf.a9f19c24.js.map