(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0af467"],{"0e40":function(e,a){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"hr",week:{dow:1,doy:7},buttonText:{prev:"Prijašnji",next:"Sljedeći",today:"Danas",month:"Mjesec",week:"Tjedan",day:"Dan",list:"Raspored"},weekText:"Tje",allDayText:"Cijeli dan",moreLinkText(e){return"+ još "+e},noEventsText:"Nema događaja za prikaz"};return e}())}}]);
//# sourceMappingURL=chunk-2d0af467.8784d39e.js.map