(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c9589"],{"596e":function(e,a){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"id",week:{dow:1,doy:7},buttonText:{prev:"mundur",next:"maju",today:"hari ini",month:"Bulan",week:"Minggu",day:"Hari",list:"Agenda"},weekText:"Mg",allDayText:"Sehari penuh",moreLinkText:"lebih",noEventsText:"Tidak ada acara untuk ditampilkan"};return e}())}}]);
//# sourceMappingURL=chunk-2d0c9589.a4004f65.js.map