(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d2131a1"],{aaf1:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"sl",week:{dow:1,doy:7},buttonText:{prev:"Prejšnji",next:"Naslednji",today:"Trenutni",month:"Mesec",week:"Teden",day:"Dan",list:"Dnevni red"},weekText:"Teden",allDayText:"Ves dan",moreLinkText:"več",noEventsText:"Ni dogodkov za prikaz"};return e}())}}]);
//# sourceMappingURL=chunk-2d2131a1.e3a86bc4.js.map