(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0cfaf6"],{6589:function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"fr",week:{dow:1,doy:4},buttonText:{prev:"Précédent",next:"Suivant",today:"Aujourd'hui",year:"Année",month:"Mois",week:"Semaine",day:"Jour",list:"Planning"},weekText:"Sem.",allDayText:"Toute la journée",moreLinkText:"en plus",noEventsText:"Aucun événement à afficher"};return e}())}}]);
//# sourceMappingURL=chunk-2d0cfaf6.c6c5e187.js.map