(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c4fd5"],{"3cd3":function(e,n){FullCalendar.globalLocales.push(function(){"use strict";var e={code:"af",week:{dow:1,doy:4},buttonText:{prev:"Vorige",next:"Volgende",today:"Vandag",year:"Jaar",month:"Maand",week:"Week",day:"Dag",list:"Agenda"},allDayText:"Heeldag",moreLinkText:"Addisionele",noEventsText:"Daar is geen gebeurtenisse nie"};return e}())}}]);
//# sourceMappingURL=chunk-2d0c4fd5.ea2a3b50.js.map