(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c7cc5"],{"51c6":function(e,n,t){"use strict";Object.defineProperty(n,"__esModule",{value:!0});var o={code:"fr-ch",week:{dow:1,doy:4},buttonText:{prev:"Précédent",next:"Suivant",today:"Courant",year:"Année",month:"Mois",week:"Semaine",day:"Jour",list:"Mon planning"},weekText:"Sm",allDayText:"Toute la journée",moreLinkText:"en plus",noEventsText:"Aucun événement à afficher"};n.default=o}}]);
//# sourceMappingURL=chunk-2d0c7cc5.03ff04a7.js.map