(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c932c"],{"57b6":function(o,e,n){(function(o,n){n(e)})(0,(function(o){"use strict";var e="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={firstDayOfWeek:1,rangeSeparator:" ĝis ",weekAbbreviation:"Sem",scrollTitle:"Rulumu por pligrandigi la valoron",toggleTitle:"Klaku por ŝalti",weekdays:{shorthand:["Dim","Lun","Mar","Mer","Ĵaŭ","Ven","Sab"],longhand:["dimanĉo","lundo","mardo","merkredo","ĵaŭdo","vendredo","sabato"]},months:{shorthand:["Jan","Feb","Mar","Apr","Maj","Jun","Jul","Aŭg","Sep","Okt","Nov","Dec"],longhand:["januaro","februaro","marto","aprilo","majo","junio","julio","aŭgusto","septembro","oktobro","novembro","decembro"]},ordinal:function(){return"-a"},time_24hr:!0};e.l10ns.eo=n;var a=e.l10ns;o.Esperanto=n,o.default=a,Object.defineProperty(o,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0c932c.ed6c7236.js.map